@@ -28,29 +28,39 @@ def flatten(items):
 
 
 def check_if_cidr(value):
-    regex = r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
-            r'\.' \
-            r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
-            r'\.' \
-            r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
-            r'\.' \
-            r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
-            r'\/' \
-            r'(3[0-2]|2[0-9]|1[0-9]|[0-9])'
-    matches = re.match(regex, value)
-
-    if matches is not None:
+    try:
+        re.compile(value)
         return True
-
-    return False
+    except TypeError as e:
+        return False
 
 
 def is_ip_in_cidr(ip_cidr, cidr):
-    for ip_network in cidr:
-        if check_if_cidr(ip_cidr) and check_if_cidr(ip_network) and IPNetwork(ip_cidr) in IPNetwork(ip_network):
-            return True
+    is_ip_regex = r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
+                  r'\.' \
+                  r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
+                  r'\.' \
+                  r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
+                  r'\.' \
+                  r'(1[0-9][0-9]|2[0-4][0-9]|25[0-5]|[0-9][0-9]|[0-9])' \
+                  r'\/' \
+                  r'(3[0-2]|2[0-9]|1[0-9]|[0-9])'
 
-    return False
+    # IP is a not a regex string
+    if re.match(is_ip_regex, ip_cidr) is not None:
+        for ip_network in cidr:
+            if check_if_cidr(ip_cidr) and check_if_cidr(ip_network) and IPNetwork(ip_cidr) in IPNetwork(ip_network):
+                return True
+
+        return False
+
+    # IP is a possible regex string
+    else:
+        # The given regex is matching the CIDR within the plan
+        for elem in cidr:
+            if re.match(ip_cidr, elem) is None:
+                return False
+        return True
 
 
 def are_networks_same(first_network, network_list):
@@ -247,7 +257,7 @@ def search_regex_in_list(regex, target_list):
 
 def seek_value_in_dict(needle, haystack, address=None):
     findings = []
-    if isinstance(haystack, (str, int, bool, float)) and needle in haystack:
+    if isinstance(haystack, (str, int, bool, float)) and str(needle) in str(haystack):
         findings.append(dict(values=needle, address=None))
 
     elif isinstance(haystack, dict):
@@ -298,3 +308,21 @@ def is_key_exist(key, target_list_of_dict):
             return True
 
     return False
+
+
+def transform_asg_style_tags(resource_list):
+    if not isinstance(resource_list, list):
+        return resource_list
+
+    for resource in resource_list:
+        tag = resource.get('values', {}).get('tag')
+
+        if not resource.get('values', {}).get('tags'):
+            resource['values']['tags'] = {}
+
+        if tag:
+            for elem in tag:
+                if 'key' in elem and 'value' in elem:
+                    resource['values']['tags'][elem['key']] = elem['value']
+
+    return resource_list
