@@ -65,13 +65,13 @@ class TestTerraformParser(TestCase):
             'root_module': {
                 'resources': [
                     {
-                        'address': 'data_something'
+                        'address': 'data.something'
                     }
                 ]
             }
         }
         obj._parse_resources()
-        self.assertEqual(obj.data['data_something'], {'address': 'data_something'})
+        self.assertEqual(obj.data['data.something'], {'address': 'data.something'})
 
 
     @patch.object(TerraformParser, '_read_file', return_value={})
@@ -97,13 +97,13 @@ class TestTerraformParser(TestCase):
             'root_module': {
                 'resources': [
                     {
-                        'address': 'data_something'
+                        'address': 'data.something'
                     }
                 ]
             }
         }
         obj._parse_resources()
-        self.assertEqual(obj.data['data_something'], {'address': 'data_something'})
+        self.assertEqual(obj.data['data.something'], {'address': 'data.something'})
 
 
     @patch.object(TerraformParser, '_read_file', return_value={})
@@ -130,14 +130,14 @@ class TestTerraformParser(TestCase):
                 'child_modules': {
                     'resources': [
                         {
-                            'address': 'data_something'
+                            'address': 'data.something'
                         }
                     ]
                 }
             }
         }
         obj._parse_resources()
-        self.assertEqual(obj.data['data_something'], {'address': 'data_something'})
+        self.assertEqual(obj.data['data.something'], {'address': 'data.something'})
 
 
     @patch.object(TerraformParser, '_read_file', return_value={})
@@ -162,7 +162,8 @@ class TestTerraformParser(TestCase):
         obj = TerraformParser('somefile', parse_it=False)
         obj.raw['resource_changes'] = [
             {
-                'address': 'data_something',
+                'mode': 'data',
+                'address': 'data.something',
                 'change': {
                     'actions': ['update'],
                     'before': {
@@ -175,7 +176,7 @@ class TestTerraformParser(TestCase):
             }
         ]
         obj._parse_resources()
-        self.assertEqual(obj.data['data_something'], {'address': 'data_something', 'values': {'key': 'bar'}})
+        self.assertEqual(obj.data['data.something'], {'address': 'data.something', 'mode': 'data', 'values': {'key': 'bar'}})
 
     @patch.object(TerraformParser, '_read_file', return_value={})
     def test_parse_resources_resources_exists_in_the_resource_changes_resource(self, *args):
@@ -336,6 +337,57 @@ class TestTerraformParser(TestCase):
         }
         self.assertEqual(obj._find_resource_from_name('resource_type.resource_id'), ['a'])
 
+    @patch.object(TerraformParser, '_read_file', return_value={})
+    def test_find_resource_from_name_resource_name_in_module_outputs_expression_references(self, *args):
+        obj = TerraformParser('somefile', parse_it=False)
+        obj.raw['configuration'] = {
+            "root_module": {
+            "module_calls": {
+                "module_name": {
+                    "source": "../../module-test",
+                    "module": {
+                        "outputs": {
+                            "my_expression": {
+                                "expression": {
+                                    "references": [
+                                        "var.example"
+                                    ]
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+            }
+        }
+        self.assertEqual(obj._find_resource_from_name('module.module_name.my_expression'), ['module.module_name.var.example'])
+
+    @patch.object(TerraformParser, '_read_file', return_value={})
+    def test_find_resource_from_name_resource_name_in_module_outputs_expression(self, *args):
+        obj = TerraformParser('somefile', parse_it=False)
+        obj.raw['configuration'] = {
+            "root_module": {
+            "module_calls": {
+                "module_name": {
+                    "source": "../../module-test",
+                    "module": {
+                        "outputs": {
+                            "my_expression": {
+                                "expression": {
+                                    "constant_value": [
+                                        "10.123.0.0/16"
+                                    ]
+                                },
+                                "description": "List of cidr(s)"
+                            }
+                        }
+                    }
+                }
+            }
+            }
+        }
+        self.assertEqual(obj._find_resource_from_name('module.module_name.my_expression'), [])
+
     @patch.object(TerraformParser, '_read_file', return_value={})
     def test_distribute_providers(self, *args):
         obj = TerraformParser('somefile', parse_it=False)
